# Copyright 2010-2014 Meik Michalke <meik.michalke@hhu.de>
#
# This file is part of the R package rkwarddev.
#
# rkwarddev is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# rkwarddev is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with rkwarddev.  If not, see <http://www.gnu.org/licenses/>.


#' Create RKWard help file skeleton
#'
#' @param summary An object of class \code{XiMpLe.node} to be pasted as the \code{<summary>} section. See
#'    \code{\link[rkwarddev:rk.rkh.summary]{rk.rkh.summary}} for details.
#' @param usage An object of class \code{XiMpLe.node} to be pasted as the \code{<usage>} section. See
#'    \code{\link[rkwarddev:rk.rkh.usage]{rk.rkh.usage}} for details.
#' @param sections A (list of) objects of class \code{XiMpLe.node} to be pasted as \code{<section>} sections. See
#'    \code{\link[rkwarddev:rk.rkh.section]{rk.rkh.section}} for details.
#' @param settings An object of class \code{XiMpLe.node} to be pasted as the \code{<settings>} section. See
#'    \code{\link[rkwarddev:rk.rkh.settings]{rk.rkh.settings}} for details.
#'    Refer to \code{\link{rk.rkh.scan}} for a function to create this from an existing plugin XML file.
#' @param related An object of class \code{XiMpLe.node} to be pasted as the \code{<related>} section. See
#'    \code{\link[rkwarddev:rk.rkh.related]{rk.rkh.related}} for details.
#' @param technical An object of class \code{XiMpLe.node} to be pasted as the \code{<technical>} section. See
#'    \code{\link[rkwarddev:rk.rkh.technical]{rk.rkh.technical}} for details.
#' @param title An object of class \code{XiMpLe.node} to be pasted as the \code{<title>} section. See
#'    \code{\link[rkwarddev:rk.rkh.title]{rk.rkh.title}} for details.
#' @param hints Logical, if \code{TRUE} and you leave out optional entries (like \code{technical=NULL}), empty dummy sections will be added.
#' @param gen.info Logical, if \code{TRUE} a comment note will be written into the document,
#'    that it was generated by \code{rkwarddev} and changes should be done to the script.
#' @param lang Character string, the language of the help page. See \code{\link[rkwarddev:i18n]{i18n}} for details.
#' @return An object of class \code{XiMpLe.doc}.
#' @seealso
#'    \code{\link[rkwarddev:rk.rkh.summary]{rk.rkh.summary}},
#'    \code{\link[rkwarddev:rk.rkh.usage]{rk.rkh.usage}},
#'    \code{\link[rkwarddev:rk.rkh.settings]{rk.rkh.settings}},
#'    \code{\link{rk.rkh.scan}},
#'    \code{\link[rkwarddev:rk.rkh.related]{rk.rkh.related}},
#'    \code{\link[rkwarddev:rk.rkh.technical]{rk.rkh.technical}}
#'    and the \href{help:rkwardplugins}{Introduction to Writing Plugins for RKWard}
#' @export

rk.rkh.doc <- function(summary=NULL, usage=NULL, sections=NULL, settings=NULL, related=NULL, technical=NULL, title=NULL, hints=TRUE, gen.info=TRUE, lang=rk.get.language()){

  all.children <- list()

  if(isTRUE(gen.info)){
    all.children[[length(all.children)+1]] <- generator.info
  } else {}

  if(!is.null(title)){
    # check if this is *really* a title section
    if(inherits(title, "XiMpLe.node")){
      title.node.name <- slot(title, "name")
    } else {
      title.node.name <- "yougottabekiddingme"
    }
    if(!identical(title.node.name, "title")){
      stop(simpleError("I don't know what this is, but 'title' is not a title section!"))
    } else {}
    all.children[[length(all.children)+1]] <- title
  } else {}

  if(!is.null(summary)){
    # check if this is *really* a summary section
    if(inherits(summary, "XiMpLe.node")){
      summary.node.name <- slot(summary, "name")
    } else {
      summary.node.name <- "yougottabekiddingme"
    }
    if(!identical(summary.node.name, "summary")){
      stop(simpleError("I don't know what this is, but 'summary' is not a summary section!"))
    } else {}
    all.children[[length(all.children)+1]] <- summary
  } else if(isTRUE(hints)){
    all.children[[length(all.children)+1]] <- rk.rkh.summary()
  } else {}

  if(!is.null(usage)){
    # check if this is *really* a usage section
    if(inherits(usage, "XiMpLe.node")){
      usage.node.name <- slot(usage, "name")
    } else {
      usage.node.name <- "yougottabekiddingme"
    }
    if(!identical(usage.node.name, "usage")){
      stop(simpleError("I don't know what this is, but 'usage' is not a usage section!"))
    } else {}
    all.children[[length(all.children)+1]] <- usage
  } else if(isTRUE(hints)){
    all.children[[length(all.children)+1]] <- rk.rkh.usage()
  } else {}

  if(!is.null(sections)){
    for(this.section in sections){
      # check if this is *really* a section
      if(inherits(this.section, "XiMpLe.node")){
        this.section.node.name <- slot(this.section, "name")
      } else {
        this.section.node.name <- "yougottabekiddingme"
      }
      if(!identical(this.section.node.name, "section")){
        stop(simpleError("I don't know what this is, but 'sections' does not hold section nodes!"))
      } else {}

      all.children[[length(all.children)+1]] <- this.section
    }
  } else if(isTRUE(hints)){
    all.children[[length(all.children)+1]] <- XMLNode("!--",
        rk.rkh.section("EDIT OR DELETE ME", text="EDIT OR DELETE ME"))
  } else {}

  if(!is.null(settings)){
    # check if this is *really* a settings section
    if(inherits(settings, "XiMpLe.node")){
      settings.node.name <- slot(settings, "name")
    } else {
      settings.node.name <- "yougottabekiddingme"
    }
    if(!identical(settings.node.name, "settings")){
      stop(simpleError("I don't know what this is, but 'settings' is not a settings section!"))
    } else {}
    all.children[[length(all.children)+1]] <- settings
  } else if(isTRUE(hints)){
    all.children[[length(all.children)+1]] <- rk.rkh.settings()
  } else {}

  if(!is.null(related)){
    # check if this is *really* a related section
    if(inherits(related, "XiMpLe.node")){
      related.node.name <- slot(related, "name")
    } else {
      related.node.name <- "yougottabekiddingme"
    }
    if(!identical(related.node.name, "related")){
      stop(simpleError("I don't know what this is, but 'related' is not a related section!"))
    } else {}
    all.children[[length(all.children)+1]] <- related
  } else if(isTRUE(hints)){
    all.children[[length(all.children)+1]] <- XMLNode("!--", rk.rkh.related(rk.rkh.link("...")))
  } else {}

  if(!is.null(technical)){
    # check if this is *really* a technical section
    if(inherits(technical, "XiMpLe.node")){
      technical.node.name <- slot(technical, "name")
    } else {
      technical.node.name <- "yougottabekiddingme"
    }
    if(!identical(technical.node.name, "technical")){
      stop(simpleError("I don't know what this is, but 'technical' is not a technical section!"))
    } else {}
    all.children[[length(all.children)+1]] <- technical
  } else if(isTRUE(hints)){
    all.children[[length(all.children)+1]] <- rk.rkh.technical()
  } else {}

  # check for possible i18n
  if(is.null(lang)){
    lang.attrs <- NULL
  } else {
    lang.attrs <- list(lang=lang, "xml:lang"=lang)
  }
  rkh.document <- XMLNode("document", attrs=lang.attrs, .children=child.list(all.children, empty=FALSE))

  rkh.main <- XMLTree(rkh.document, dtd=list(doctype="rkhelp"))

  return(rkh.main)
}
